@@ -18,7 +18,7 @@
 #ifndef _HAPROXY_TCPCHECK_T_H
 #define _HAPROXY_TCPCHECK_T_H
 
-#include <import/ebpttree.h>
+#include <import/ebtree-t.h>
 #include <import/ist.h>
 #include <haproxy/api-t.h>
 #include <haproxy/buf-t.h>
